<?php
/**
 * Copyright 2018 Smartwaiver
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain
 * a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations
 * under the License.
 */

namespace Smartwaiver\Tests;

use InvalidArgumentException;
use Smartwaiver\Tests\Factories\SmartwaiverTypes;
use Smartwaiver\Types\SmartwaiverPhoto;

/**
 * Class SmartwaiverPhotoTest
 *
 * @package Smartwaiver\Tests
 */
class SmartwaiverPhotoTest extends \PHPUnit_Framework_TestCase
{
    /**
     * Test whether a required keys error is generated correctly
     */
    public function testRequiredKeys()
    {
        $this->expectException(InvalidArgumentException::class);
        $this->expectExceptionMessage('Cannot create a SmartwaiverPhoto with missing field: type');

        $photo = SmartwaiverTypes::createPhoto();
        unset($photo['type']);

        $swPhoto = new SmartwaiverPhoto($photo);
    }

    /**
     * Test whether all data values are correctly assigned
     */
    public function testSuccess()
    {
        $photo = SmartwaiverTypes::createPhoto();
        $swPhoto = new SmartwaiverPhoto($photo);

        $this->assertEquals($photo['type'], $swPhoto->type);
        $this->assertEquals($photo['date'], $swPhoto->date);
        $this->assertEquals($photo['tag'], $swPhoto->tag);
        $this->assertEquals($photo['fileType'], $swPhoto->fileType);
        $this->assertEquals($photo['photoId'], $swPhoto->photoId);
        $this->assertEquals($photo['photo'], $swPhoto->photo);
    }
}
